@@ -46,8 +46,8 @@ def eval_conditional_density(
         eps_margins2: We will evaluate the posterior along `dim2` at
             `limits[0]+eps_margins` until `limits[1]-eps_margins`. This avoids
             evaluations potentially exactly at the prior bounds.
-	return_raw_log_prob: If `True`, return the log-probability evaluated on the·
-            grid. If `False`, return the probability, scaled down by the maximum value·
+        return_raw_log_prob: If `True`, return the log-probability evaluated on the
+            grid. If `False`, return the probability, scaled down by the maximum value
             on the grid for numerical stability (i.e. exp(log_prob - max_log_prob)).
 
     Returns: Conditional probabilities. If `dim1 == dim2`, this will have shape
