@@ -322,7 +322,7 @@ class RatioEstimator(NeuralInference, ABC):
             device = self._device
         else:
             # Otherwise, infer it from the device of the net parameters.
-            device = next(density_estimator.parameters()).device
+            device = next(density_estimator.parameters()).device.type
 
         self._posterior = RatioBasedPosterior(
             method_family=self.__class__.__name__.lower(),
