@@ -12,7 +12,9 @@ from torch.distributions import MultivariateNormal
 
 from sbi import analysis as analysis
 from sbi import utils as utils
+
 from sbi.inference import SNPE_A, SNPE_B, SNPE_C, prepare_for_sbi, simulate_for_sbi
+
 from sbi.simulators.linear_gaussian import (
     linear_gaussian,
     samples_true_posterior_linear_gaussian_mvn_prior_different_dims,
@@ -26,6 +28,8 @@ from tests.test_utils import (
     get_prob_outside_uniform_prior,
 )
 
+from tests.sbiutils_test import conditional_of_mvn
+
 
 @pytest.mark.parametrize("snpe_method", [SNPE_A, SNPE_C])
 @pytest.mark.parametrize(
@@ -73,6 +77,7 @@ def test_c2st_snpe_on_linearGaussian(
     simulator, prior = prepare_for_sbi(
         lambda theta: linear_gaussian(theta, likelihood_shift, likelihood_cov), prior
     )
+
     inference = snpe_method(prior, show_progress_bars=False)
 
     theta, x = simulate_for_sbi(
@@ -176,6 +181,7 @@ def test_c2st_snpe_on_linearGaussian_different_dims(set_seed):
 
     # type: ignore
     theta, x = simulate_for_sbi(simulator, prior, 2000, simulation_batch_size=1)
+
     inference = inference.append_simulations(theta, x)
     _ = inference.train(max_num_epochs=10)  # Test whether we can stop and resume.
     _ = inference.train(resume_training=True)
@@ -288,20 +294,17 @@ def test_c2st_multi_round_snpe_on_linearGaussian(method_str: str, set_seed):
 
 # Testing rejection and mcmc sampling methods.
 @pytest.mark.slow
-@pytest.mark.parametrize("snpe_method", [SNPE_A, SNPE_C])
 @pytest.mark.parametrize(
-    "sample_with_mcmc, mcmc_method, prior_str",
+    "sample_with, mcmc_method, prior_str",
     (
-        (True, "slice_np", "gaussian"),
-        (True, "slice", "gaussian"),
+        ("mcmc", "slice_np", "gaussian"),
+        ("mcmc", "slice", "gaussian"),
         # XXX (True, "slice", "uniform"),
         # XXX takes very long. fix when refactoring pyro sampling
-        (False, "rejection", "uniform"),
+        ("rejection", "rejection", "uniform"),
     ),
 )
-def test_api_snpe_c_posterior_correction(
-    snpe_method: type, sample_with_mcmc, mcmc_method, prior_str, set_seed
-):
+def test_api_snpe_c_posterior_correction(sample_with, mcmc_method, prior_str, set_seed):
     """Test that leakage correction applied to sampling works, with both MCMC and
     rejection.
 
@@ -326,10 +329,10 @@ def test_api_snpe_c_posterior_correction(
     simulator, prior = prepare_for_sbi(
         lambda theta: linear_gaussian(theta, likelihood_shift, likelihood_cov), prior
     )
-    inference = snpe_method(
+    inference = SNPE_C(
         prior,
         simulation_batch_size=50,
-        sample_with_mcmc=sample_with_mcmc,
+        sample_with=sample_with,
         mcmc_method=mcmc_method,
         show_progress_bars=False,
     )
@@ -338,9 +341,7 @@ def test_api_snpe_c_posterior_correction(
     _ = inference.append_simulations(theta, x).train(max_num_epochs=5)
 
     posterior = inference.build_posterior()
-    posterior = posterior.set_sample_with_mcmc(sample_with_mcmc).set_mcmc_method(
-        mcmc_method
-    )
+    posterior = posterior.set_sample_with(sample_with).set_mcmc_method(mcmc_method)
 
     # Posterior should be corrected for leakage even if num_rounds just 1.
     samples = posterior.sample((10,), x=x_o)
@@ -350,8 +351,7 @@ def test_api_snpe_c_posterior_correction(
 
 
 @pytest.mark.slow
-@pytest.mark.parametrize("snpe_method", [SNPE_A, SNPE_C])
-def test_sample_conditional(snpe_method: type, set_seed):
+def test_sample_conditional(set_seed):
     """
     Test whether sampling from the conditional gives the same results as evaluating.
 
@@ -379,13 +379,11 @@ def test_sample_conditional(snpe_method: type, set_seed):
         else:
             return linear_gaussian(theta, -likelihood_shift, likelihood_cov)
 
-    if snpe_method == SNPE_A:
-        net = utils.posterior_nn("mdn_snpe_a", hidden_features=20)
-    else:
-        net = utils.posterior_nn("maf", hidden_features=20)
+    net = utils.posterior_nn("maf", hidden_features=20)
 
     simulator, prior = prepare_for_sbi(simulator, prior)
-    inference = snpe_method(prior, density_estimator=net, show_progress_bars=False)
+
+    inference = SNPE_C(prior, density_estimator=net, show_progress_bars=False)
 
     # We need a pretty big dataset to properly model the bimodality.
     theta, x = simulate_for_sbi(simulator, prior, 10000)
@@ -434,7 +432,76 @@ def test_sample_conditional(snpe_method: type, set_seed):
     error = np.abs(sample_kde_grid - eval_grid.numpy())
 
     max_err = np.max(error)
-    assert max_err < 0.0025
+    assert max_err < 0.0026
+
+
+@pytest.mark.slow
+def test_mdn_conditional_density(num_dim: int = 3, cond_dim: int = 1):
+    """Test whether the conditional density infered from MDN parameters of a
+    `DirectPosterior` matches analytical results for MVN. This uses a n-D joint and
+    conditions on the last m values to generate a conditional.
+
+    Gaussian prior used for easier ground truthing of conditional posterior.
+
+    Args:
+        num_dim: Dimensionality of the MVM.
+        cond_dim: Dimensionality of the condition.
+    """
+
+    assert (
+        num_dim > cond_dim
+    ), "The number of dimensions needs to be greater than that of the condition!"
+
+    x_o = zeros(1, num_dim)
+    num_samples = 1000
+    num_simulations = 2500
+    condition = 0.1 * ones(1, num_dim)
+
+    dims = list(range(num_dim))
+    dims2sample = dims[-cond_dim:]
+    dims2condition = dims[:-cond_dim]
+
+    # likelihood_mean will be likelihood_shift+theta
+    likelihood_shift = -1.0 * ones(num_dim)
+    likelihood_cov = 0.3 * eye(num_dim)
+
+    prior_mean = zeros(num_dim)
+    prior_cov = eye(num_dim)
+    prior = MultivariateNormal(loc=prior_mean, covariance_matrix=prior_cov)
+
+    joint_posterior = true_posterior_linear_gaussian_mvn_prior(
+        x_o[0], likelihood_shift, likelihood_cov, prior_mean, prior_cov
+    )
+    joint_cov = joint_posterior.covariance_matrix
+    joint_mean = joint_posterior.loc
+
+    conditional_mean, conditional_cov = conditional_of_mvn(
+        joint_mean, joint_cov, condition[0, dims2condition]
+    )
+    conditional_dist_gt = MultivariateNormal(conditional_mean, conditional_cov)
+
+    conditional_samples_gt = conditional_dist_gt.sample((num_samples,))
+
+    def simulator(theta):
+        return linear_gaussian(theta, likelihood_shift, likelihood_cov)
+
+    simulator, prior = prepare_for_sbi(simulator, prior)
+    inference = SNPE_C(prior, show_progress_bars=False, density_estimator="mdn")
+
+    theta, x = simulate_for_sbi(
+        simulator, prior, num_simulations, simulation_batch_size=1000
+    )
+    _ = inference.append_simulations(theta, x).train(training_batch_size=100)
+    posterior = inference.build_posterior().set_default_x(x_o)
+
+    conditional_samples_sbi = posterior.sample_conditional(
+        (num_samples,), condition, dims2sample, x_o
+    )
+    check_c2st(
+        conditional_samples_sbi,
+        conditional_samples_gt,
+        alg="analytic_mdn_conditioning_of_direct_posterior",
+    )
 
 
 @pytest.mark.parametrize("snpe_method", [SNPE_A, SNPE_C])
@@ -460,6 +527,7 @@ def test_example_posterior(snpe_method: type):
         lambda theta: linear_gaussian(theta, likelihood_shift, likelihood_cov), prior
     )
     inference = snpe_method(prior, show_progress_bars=False, **extra_kwargs)
+
     theta, x = simulate_for_sbi(
         simulator, prior, 1000, simulation_batch_size=10, num_workers=6
     )
